@@ -115,9 +115,11 @@ def main():
     parser_record.add_argument(
         '--path', help='Cognicept configuration directory (default: `' + DEFAULT_PATH + '`)', default=DEFAULT_PATH)
     parser_record.add_argument(
-        '--start', help='Start rosbag recording session. Provide topics to record separated by spaces. e.g. cognicept record --start rosout odom', nargs='+')
+        '--start', help='Start rosbag recording session. Provide topics to record separated by spaces with their `/` prefix. e.g. cognicept record --start /rosout /odom', nargs='+')
     parser_record.add_argument(
-        '--stop', help='Stop rosbag recording session', action='store_true')
+        '--all', help='Start rosbag recording session to record ALL topics.', action='store_true')
+    parser_record.add_argument(
+        '--stop', help='Stop rosbag recording session. Set `STOP` to `autopush` to automatically push latest bag to the Cognicept cloud after stopping', type=str, const='nopush', nargs='?')
     parser_record.add_argument(
         '--pause', help='Pause rosbag recording session', action='store_true')
     parser_record.add_argument(
@@ -130,7 +132,7 @@ def main():
     parser_push.add_argument(
         '--path', help='Cognicept configuration directory (default: `' + DEFAULT_PATH + '`)', default=DEFAULT_PATH)
     parser_push.add_argument(
-        '--bag', help='Pushes rosbag to the configured S3 bucket. Set to BAG to latest to upload latest bag')
+        '--bag', help='Pushes rosbag to the Cognicept cloud. By default it pushes the latest bag file recording. Set `BAG` to appropriate bag name in the `PATH` folder to upload a rosbag by name', type=str, const='latest', nargs='?')
     # Parse the arguments
     args = parser.parse_args()
 
