@@ -2,7 +2,6 @@
 import pytest
 import re
 import requests
-import jwt
 import datetime
 import os
 import boto3, botocore
@@ -22,6 +21,26 @@ class NotFoundLoginResponse(object):
     def __init__(self):
         self.status_code = 404
 
+
+class SuccessAwsCredentials(object):
+    def __init__(self):
+        self.status_code = 200
+
+    def json(self):
+        return {"AccessKeyId": os.getenv('AWS_ACCESS_KEY_ID', ""), "SecretAccessKey": os.getenv('AWS_SECRET_ACCESS_KEY', ""), "SessionToken": ""}
+
+
+class NotFoundMockResponse(object):
+    def __init__(self):
+        self.status_code = 404
+
+
+def mock_aws_endpoint(*args, **kwargs):
+    if(args[0] == "https://test.cognicept.systems/api/agent/v1/aws/assume_role"):
+        return SuccessAwsCredentials()
+    else:
+        return NotFoundMockResponse()
+
 def mock_ecr_endpoint(*args, **kwargs):
     if(args[0] == "https://test.cognicept.systems/api/v1/aws/assume_role/ecr"):
         return SuccessEcrCredentials()
@@ -42,13 +61,11 @@ def setup_wrong_file(tmpdir):
 
 def setup_test_docker_file(tmpdir):
     p = tmpdir.join("runtime.env")
-    payload = jwt.encode({'exp': datetime.datetime.utcnow() + datetime.timedelta(seconds=30)}, 'secret')
-    p.write("AWS_ACCESS_KEY_ID=TESTKEY\nAWS_SECRET_ACCESS_KEY=TESTKEY\nAWS_SESSION_TOKEN=TESTTOKEN\nCOG_AGENT_CONTAINERS=test\nCOG_AGENT_IMAGES=ubuntu:latest\nCOGNICEPT_API_URI=https://test.cognicept.systems/api/v1/\nCOGNICEPT_JWT=" + payload.decode("utf-8") )
+    p.write("AWS_ACCESS_KEY_ID=TESTKEY\nAWS_SECRET_ACCESS_KEY=TESTKEY\nAWS_SESSION_TOKEN=TESTTOKEN\nCOG_AGENT_CONTAINERS=test\nCOG_AGENT_IMAGES=ubuntu:latest\nCOGNICEPT_API_URI=https://test.cognicept.systems/api/agent/v1/\nCOGNICEPT_ACCESS_KEY=CORRECT-KEY")
 
 def setup_wrong_api(tmpdir):
     p = tmpdir.join("runtime.env")
-    payload = jwt.encode({'exp': datetime.datetime.utcnow() + datetime.timedelta(seconds=30)}, 'secret')
-    p.write("COG_AGENT_CONTAINERS=test\nCOG_AGENT_IMAGES=ubuntu:latest\nCOGNICEPT_API_URI=https://wrongaddress.com/\nCOGNICEPT_JWT=" + payload.decode("utf-8") )
+    p.write("COG_AGENT_CONTAINERS=test\nCOG_AGENT_IMAGES=ubuntu:latest\nCOGNICEPT_API_URI=https://wrongaddress.com/")
 
 
 def setup_logs(tmpdir):
@@ -154,7 +171,7 @@ def test_latest_log_loc(tmpdir):
     setup_logs(tmpdir)
 
     agent_lifecycle = AgentLifeCycle()
-    returned_location = agent_lifecycle.get_latest_log_loc(args)
+    returned_location = agent_lifecycle._get_latest_log_loc(args)
 
     assert(returned_location == "agent/logs/directory")
 
@@ -183,7 +200,7 @@ def test_parsing_ok_ria_logs(capsys):
 [ INFO] [1594729019.166115169]: WEBSOCKET:: STATUS:: OK
 [ INFO] [1594729019.169204677]: AGENT:: STATUS:: OK"""
     capsys.readouterr().out
-    agent_lifecycle.parseRemoteInterventionAgentLogs(log)
+    agent_lifecycle._parse_remote_intervention_agent_logs(log)
     output = str(capsys.readouterr().out)
     matches = re.findall(r"ONLINE", output, re.MULTILINE)
     assert len(matches) == 1
@@ -193,7 +210,7 @@ def test_parsing_not_init_ria_logs(capsys):
 
     log = """[ INFO] [1594729019.169204677]: WEBSOCKET:: STATUS:: INIT"""
     capsys.readouterr().out
-    agent_lifecycle.parseRemoteInterventionAgentLogs(log)
+    agent_lifecycle._parse_remote_intervention_agent_logs(log)
     output = str(capsys.readouterr().out)
     matches = re.findall(r"NOT INITIALIZED", output, re.MULTILINE)
     assert len(matches) == 1
@@ -208,7 +225,7 @@ def test_parsing_agent_error_ria_logs(capsys):
 [ INFO] [1594729019.166115169]: WEBSOCKET:: STATUS:: OK
 [ INFO] [1594729019.169204677]: AGENT:: STATUS:: ERROR"""
     capsys.readouterr().out
-    agent_lifecycle.parseRemoteInterventionAgentLogs(log)
+    agent_lifecycle._parse_remote_intervention_agent_logs(log)
     output = str(capsys.readouterr().out)
     matches = re.findall(r"ERROR", output, re.MULTILINE)
     assert len(matches) == 1
@@ -223,7 +240,7 @@ def test_parsing_websocket_error_ria_logs(capsys):
 [ INFO] [1594729019.166115169]: WEBSOCKET:: STATUS:: ERROR
 [ INFO] [1594729019.169204677]: AGENT:: STATUS:: OK"""
     capsys.readouterr().out
-    agent_lifecycle.parseRemoteInterventionAgentLogs(log)
+    agent_lifecycle._parse_remote_intervention_agent_logs(log)
     output = str(capsys.readouterr().out)
     matches = re.findall(r"ERROR", output, re.MULTILINE)
     assert len(matches) == 1
@@ -238,7 +255,7 @@ def test_parsing_webrtc_error_ria_logs(capsys):
 [ INFO] [1594729019.166115169]: WEBSOCKET:: STATUS:: OK
 [ INFO] [1594729019.169204677]: AGENT:: STATUS:: OK"""
     capsys.readouterr().out
-    agent_lifecycle.parseRemoteInterventionAgentLogs(log)
+    agent_lifecycle._parse_remote_intervention_agent_logs(log)
     output = str(capsys.readouterr().out)
     matches = re.findall(r"ERROR", output, re.MULTILINE)
     assert len(matches) == 1
@@ -322,12 +339,7 @@ def test_agent_restart(tmpdir, capsys):
     assert result == True
 
 
-def test_correct_ecr_credentials(tmpdir):
-    try:  
-        os.environ["AWS_ACCESS_KEY_ID"]
-        os.environ["AWS_SECRET_ACCESS_KEY"]
-    except KeyError: 
-        pytest.skip("AWS credentials are not defined.")
+def test_correct_ecr_credentials(tmpdir, capsys, monkeypatch):
 
     # setup runtime variables
     setup_test_docker_file(tmpdir)
@@ -344,6 +356,7 @@ def test_correct_ecr_credentials(tmpdir):
         agent_lifecycle = AgentLifeCycle()
         agent_lifecycle.configure_containers(local_cfg)
         try:
+            monkeypatch.setattr(requests, "get", mock_aws_endpoint)
             result = agent_lifecycle.update(args)            
         except boto3.exceptions.Boto3Error:
             result = True
@@ -372,6 +385,7 @@ def test_wrong_ecr_credentials(tmpdir):
         try:
             result = agent_lifecycle.update(args)       
         except Exception:
+            print('Update failed')
             result = True
 
-    assert(result == False)
\ No newline at end of file
+    assert(result == False)
